==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/settings/l10n/et_EE.js <==
OC.L10N.register(
    "settings",
    {
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Security & setup warnings" : "Turva- ja paigalduse hoiatused",
    "Sharing" : "Jagamine",
    "Server-side encryption" : "Serveripoolne krüpteerimine",
    "External Storage" : "Väline salvestuskoht",
    "Cron" : "Cron",
    "Email server" : "E-kirjade server",
    "Log" : "Logi",
    "Tips & tricks" : "Nõuanded ja trikid",
    "Updates" : "Uuendused",
    "Authentication error" : "Autentimise viga",
    "Your full name has been changed." : "Sinu täispikk nimi on muudetud.",
    "Unable to change full name" : "Täispika nime muutmine ebaõnnestus",
    "Couldn't remove app." : "Ei suutnud rakendit eemaldada.",
    "Language changed" : "Keel on muudetud",
    "Invalid request" : "Vigane päring",
    "Admins can't remove themself from the admin group" : "Administraatorid ei saa ise end admin grupist eemaldada",
    "Unable to add user to group %s" : "Kasutajat ei saa lisada gruppi %s",
    "Unable to remove user from group %s" : "Kasutajat ei saa eemaldada grupist %s",
    "Couldn't update app." : "Rakenduse uuendamine ebaõnnestus.",
    "Wrong password" : "Vale parool",
    "No user supplied" : "Kasutajat ei sisestatud",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Palun sisesta administraatori taasteparool, muidu kaotad kõik kasutajate andmed",
    "Wrong admin recovery password. Please check the password and try again." : "Vale administraatori taasteparool. Palun kontrolli parooli ning proovi uuesti.",
    "Unable to change password" : "Ei suuda parooli muuta",
    "Enabled" : "Sisse lülitatud",
    "Not enabled" : "Pole sisse lülitatud",
    "Migration Completed" : "Kolimine on lõpetatud",
    "Group already exists." : "Grupp on juba olemas.",
    "Unable to add group." : "Gruppi lisamine ebaõnnestus.",
    "Unable to delete group." : "Grupi kustutamineebaõnnestus.",
    "Saved" : "Salvestatud",
    "test email settings" : "testi e-posti seadeid",
    "Email sent" : "E-kiri on saadetud",
    "You need to set your user email before being able to send test emails." : "Pead seadistama oma e-postienne kui on võimalik saata test-kirju.",
    "Invalid mail address" : "Vigane e-posti aadress",
    "A user with that name already exists." : "Selle nimega kasutaja on juba olemas.",
    "Unable to create user." : "Kasutaja loomine ebaõnnestus.",
    "Your %s account was created" : "Sinu %s konto on loodud",
    "Unable to delete user." : "Kasutaja kustutamine ebaõnnestus.",
    "Forbidden" : "Keelatud",
    "Invalid user" : "Vigane kasutaja",
    "Unable to change mail address" : "E-posti aadressi muutmine ebaõnnestus",
    "Email saved" : "Kiri on salvestatud",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Oled sa kindel, et soovid lisada domeeni \"{domain}\" usaldusväärseks domeeniks?",
    "Add trusted domain" : "Lis ausaldusväärne domeen",
    "Migration started …" : "Kolimist on alustatud ...",
    "Sending..." : "Saadan...",
    "Official" : "Ametlik",
    "Approved" : "Heaks kiidetud",
    "Experimental" : "Katsetusjärgus",
    "All" : "Kõik",
    "Update to %s" : "Uuenda versioonile %s",
    "Please wait...." : "Palun oota...",
    "Error while disabling app" : "Viga rakenduse keelamisel",
    "Disable" : "Lülita välja",
    "Enable" : "Lülita sisse",
    "Error while enabling app" : "Viga rakenduse lubamisel",
    "Updating...." : "Uuendamine...",
    "Error while updating app" : "Viga rakenduse uuendamisel",
    "Updated" : "Uuendatud",
    "Uninstalling ...." : "Eemaldan...",
    "Error while uninstalling app" : "Viga rakendi eemaldamisel",
    "Uninstall" : "Eemalda",
    "Select a profile picture" : "Vali profiili pilt",
    "Very weak password" : "Väga nõrk parool",
    "Weak password" : "Nõrk parool",
    "So-so password" : "Enam-vähem sobiv parool",
    "Good password" : "Hea parool",
    "Strong password" : "Väga hea parool",
    "Valid until {date}" : "Kehtib kuni {date}",
    "Delete" : "Kustuta",
    "Groups" : "Grupid",
    "Unable to delete {objName}" : "Ei suuda kustutada {objName}",
    "Error creating group" : "Viga grupi loomisel",
    "A valid group name must be provided" : "Sisesta nõuetele vastav grupi nimi",
    "deleted {groupName}" : "kustutatud {groupName}",
    "undo" : "tagasi",
    "no group" : "grupp puudub",
    "never" : "mitte kunagi",
    "deleted {userName}" : "kustutatud {userName}",
    "add group" : "lisa grupp",
    "A valid username must be provided" : "Sisesta nõuetele vastav kasutajatunnus",
    "Error creating user" : "Viga kasutaja loomisel",
    "A valid password must be provided" : "Sisesta nõuetele vastav parool",
    "A valid email must be provided" : "Sisesta kehtiv e-posti aadress",
    "__language_name__" : "Eesti",
    "Sync clients" : "Klientide sünkroniseerimine",
    "Personal info" : "Isiklik info",
    "SSL root certificates" : "SSL root sertifikaadid",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Kõik (tõsised probleemid, veateated, hoiatused, info, veatuvastus)",
    "Info, warnings, errors and fatal issues" : "Info, hoiatused, veateted ja tõsised probleemid",
    "Warnings, errors and fatal issues" : "Hoiatused, veateated ja tõsised probleemid",
    "Errors and fatal issues" : "Veateated ja tõsised probleemid",
    "Fatal issues only" : "Ainult tõsised probleemid",
    "None" : "Pole",
    "Login" : "Logi sisse",
    "Plain" : "Tavatekst",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP on seadistatud eemaldama \"inline\" dokumendi blokke. See muudab mõned rakendid kasutamatuteks.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP moodul 'fileinfo' puudub. Soovitame tungivalt see lisada saavutamaks parimaid tulemusi failitüüpide tuvastamisel.",
    "System locale can not be set to a one which supports UTF-8." : "Süsteemi lokaliseeringuks ei saa panna sellist, mis toetab UTF-8-t.",
    "This means that there might be problems with certain characters in file names." : "See tähendab, et võib esineda probleeme failide nimedes mõnede sümbolitega.",
    "All checks passed." : "Kõik kontrollid on läbitud.",
    "Open documentation" : "Ava dokumentatsioon",
    "Allow apps to use the Share API" : "Luba rakendustel kasutada Share API-t",
    "Allow users to share via link" : "Luba kasutajatel lingiga jagamist ",
    "Enforce password protection" : "Sunni parooliga kaitsmist",
    "Allow public uploads" : "Luba avalikud üleslaadimised",
    "Allow users to send mail notification for shared files" : "Luba kasutajatel saata e-posti teavitusi jagatud failide kohta",
    "Set default expiration date" : "Määra vaikimisi aegumise kuupäev",
    "Expire after " : "Aegu pärast",
    "days" : "päeva",
    "Enforce expiration date" : "Sunnitud aegumise kuupäev",
    "Allow resharing" : "Luba edasijagamine",
    "Restrict users to only share with users in their groups" : "Luba kasutajatel jagada kasutajatega ainult oma grupi piires",
    "Exclude groups from sharing" : "Eemalda grupid jagamisest",
    "These groups will still be able to receive shares, but not to initiate them." : "Need grupid saavad vastu võtta jagamisi, kuid ise jagamisi algatada ei saa.",
    "Last cron job execution: %s." : "Cron käivitati viimati %s.",
    "Last cron job execution: %s. Something seems wrong." : "Cron käivitati viimati %s. Midagi tunduv valesti olevat.",
    "Cron was not executed yet!" : "Cron pole kordagi käivitatud!",
    "Execute one task with each page loaded" : "Käivita toiming igal lehe laadimisel",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php on registreeritud webcron teenuses, et käivitada fail cron.php iga 15 minuti tagant üle http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Kasuta süsteemi cron teenust, et käivitada fail cron.php iga 15 minuti järel.",
    "Enable server-side encryption" : "Luba serveripoolne krüpteerimine",
    "Enable encryption" : "Luba krüpteerimine",
    "Select default encryption module:" : "Määra vaikimisi krüpteerimise moodul:",
    "Start migration" : "Alusta kolimist",
    "This is used for sending out notifications." : "Seda kasutatakse teadete välja saatmiseks.",
    "Send mode" : "Saatmise viis",
    "Encryption" : "Krüpteerimine",
    "From address" : "Saatja aadress",
    "mail" : "e-mail",
    "Authentication method" : "Autentimise meetod",
    "Authentication required" : "Autentimine on vajalik",
    "Server address" : "Serveri aadress",
    "Port" : "Port",
    "Credentials" : "Kasutajatunnused",
    "SMTP Username" : "SMTP kasutajatunnus",
    "SMTP Password" : "SMTP parool",
    "Store credentials" : "Säilita kasutajaandmed",
    "Test email settings" : "Testi e-posti seadeid",
    "Send email" : "Saada kiri",
    "Log level" : "Logi tase",
    "Download logfile" : "Laadi logifail alla",
    "More" : "Rohkem",
    "Less" : "Vähem",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Logifail on suurem kui 100 MB. Allalaadimine võib veidi aega võtta!",
    "How to do backups" : "Kuidas teha varukoopiaid",
    "Advanced monitoring" : "Lisavalikutega jälgimine",
    "Performance tuning" : "Kiiruse seadistamine",
    "Improving the config.php" : "config.php faili täiendamine",
    "Theming" : "Teemad",
    "Version" : "Versioon",
    "Developer documentation" : "Arendaja dokumentatsioon",
    "Experimental applications ahead" : "Ees on katsetusjärgus rakendused",
    "by" : "lisas",
    "licensed" : "litsenseeritud",
    "Documentation:" : "Dokumentatsioon:",
    "User documentation" : "Kasutaja dokumentatsioon",
    "Admin documentation" : "Administraatori dokumentatsioon",
    "Show description …" : "Näita kirjeldist ...",
    "Hide description …" : "Peida kirjeldus ...",
    "Enable only for specific groups" : "Luba ainult kindlad grupid",
    "Uninstall App" : "Eemada rakend",
    "Enable experimental apps" : "Luba katsetusjärgus rakenduste kasutamine",
    "No apps found for your version" : "Sinu versiooni jaoks ei leitud ühtegi rakendust",
    "Cheers!" : "Terekest!",
    "Administrator documentation" : "Administraatori dokumentatsioon",
    "Online documentation" : "Võrgus olev dokumentatsioon",
    "Forum" : "Foorum",
    "Issue tracker" : "Probleemide jälgija",
    "Commercial support" : "Tasuline kasutajatugi",
    "Get the apps to sync your files" : "Hangi rakendusi failide sünkroniseerimiseks",
    "Desktop client" : "Töölaua klient",
    "Android app" : "Androidi rakendus",
    "iOS app" : "iOS-i rakendus",
    "Show First Run Wizard again" : "Näita veelkord Esmase Käivituse Juhendajat",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Kasutad <strong>%s</strong> saadavalolevast <strong>%s</strong>",
    "Password" : "Parool",
    "Unable to change your password" : "Sa ei saa oma parooli muuta",
    "Current password" : "Praegune parool",
    "New password" : "Uus parool",
    "Change password" : "Muuda parooli",
    "Full name" : "Täielik nimi",
    "No display name set" : "Näidatavat nime pole veel määratud",
    "Email" : "E-post",
    "Your email address" : "Sinu e-posti aadress",
    "Fill in an email address to enable password recovery and receive notifications" : "Täida e-posti aadress võimaldamaks parooli taastamist ning teadete saamist.",
    "No email address set" : "E-posti aadressi pole veel määratud",
    "Profile picture" : "Profiili pilt",
    "Upload new" : "Laadi uus üles",
    "Select new from Files" : "Vali failidest uus",
    "Remove image" : "Eemalda pilt",
    "Your avatar is provided by your original account." : "Sinu avatari pakub sinu algne konto.",
    "Cancel" : "Loobu",
    "Choose as profile image" : "Vali profiilipildiks",
    "Language" : "Keel",
    "Help translate" : "Aita tõlkida",
    "Common Name" : "Üldnimetus",
    "Valid until" : "Kehtib kuni",
    "Issued By" : "isas",
    "Valid until %s" : "Kehtib kuni %s",
    "Import root certificate" : "Impordi root sertifikaat",
    "Show storage location" : "Näita salvestusruumi asukohta",
    "Show last log in" : "Viimane sisselogimine",
    "Send email to new user" : "Saada uuele kasutajale e-kiri",
    "Show email address" : "Näita e-posti aadressi",
    "Username" : "Kasutajanimi",
    "E-Mail" : "E-post",
    "Create" : "Lisa",
    "Admin Recovery Password" : "Admini parooli taastamine",
    "Enter the recovery password in order to recover the users files during password change" : "Sisesta taasteparool kasutaja failide taastamiseks paroolivahetuse käigus",
    "Add Group" : "Lisa grupp",
    "Group" : "Grupp",
    "Everyone" : "Igaüks",
    "Admins" : "Haldurid",
    "Default Quota" : "Vaikimisi kvoot",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Palun sisesta mahupiir (nt: \"512 MB\" või \"12 GB\")",
    "Unlimited" : "Piiramatult",
    "Other" : "Muu",
    "Full Name" : "Täispikk nimi",
    "Group Admin for" : "Grupi admin",
    "Quota" : "Mahupiir",
    "Storage Location" : "Mahu asukoht",
    "Last Login" : "Viimane sisselogimine",
    "change full name" : "Muuda täispikka nime",
    "set new password" : "määra uus parool",
    "change email address" : "muuda e-posti aadressi",
    "Default" : "Vaikeväärtus"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/settings/l10n/et_EE.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Vale parool",
    "No user supplied" : "Kasutajat ei sisestatud",
    "Authentication error" : "Autentimise viga",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Palun sisesta administraatori taasteparool, muidu kaotad kõik kasutajate andmed",
    "Wrong admin recovery password. Please check the password and try again." : "Vale administraatori taasteparool. Palun kontrolli parooli ning proovi uuesti.",
    "Unable to change password" : "Ei suuda parooli muuta",
    "Enabled" : "Sisse lülitatud",
    "Not enabled" : "Pole sisse lülitatud",
    "Migration Completed" : "Kolimine on lõpetatud",
    "Group already exists." : "Grupp on juba olemas.",
    "Unable to add group." : "Gruppi lisamine ebaõnnestus.",
    "Unable to delete group." : "Grupi kustutamineebaõnnestus.",
    "Saved" : "Salvestatud",
    "test email settings" : "testi e-posti seadeid",
    "Email sent" : "E-kiri on saadetud",
    "You need to set your user email before being able to send test emails." : "Pead seadistama oma e-postienne kui on võimalik saata test-kirju.",
    "Invalid mail address" : "Vigane e-posti aadress",
    "A user with that name already exists." : "Selle nimega kasutaja on juba olemas.",
    "Unable to create user." : "Kasutaja loomine ebaõnnestus.",
    "Your %s account was created" : "Sinu %s konto on loodud",
    "Unable to delete user." : "Kasutaja kustutamine ebaõnnestus.",
    "Forbidden" : "Keelatud",
    "Invalid user" : "Vigane kasutaja",
    "Unable to change mail address" : "E-posti aadressi muutmine ebaõnnestus",
    "Email saved" : "Kiri on salvestatud",
    "Your full name has been changed." : "Sinu täispikk nimi on muudetud.",
    "Unable to change full name" : "Täispika nime muutmine ebaõnnestus",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Security & setup warnings" : "Turva- ja paigalduse hoiatused",
    "Sharing" : "Jagamine",
    "Server-side encryption" : "Serveripoolne krüpteerimine",
    "External Storage" : "Väline salvestuskoht",
    "Cron" : "Cron",
    "Email server" : "E-kirjade server",
    "Log" : "Logi",
    "Tips & tricks" : "Nõuanded ja trikid",
    "Updates" : "Uuendused",
    "Couldn't remove app." : "Ei suutnud rakendit eemaldada.",
    "Language changed" : "Keel on muudetud",
    "Invalid request" : "Vigane päring",
    "Admins can't remove themself from the admin group" : "Administraatorid ei saa ise end admin grupist eemaldada",
    "Unable to add user to group %s" : "Kasutajat ei saa lisada gruppi %s",
    "Unable to remove user from group %s" : "Kasutajat ei saa eemaldada grupist %s",
    "Couldn't update app." : "Rakenduse uuendamine ebaõnnestus.",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Oled sa kindel, et soovid lisada domeeni \"{domain}\" usaldusväärseks domeeniks?",
    "Add trusted domain" : "Lis ausaldusväärne domeen",
    "Migration in progress. Please wait until the migration is finished" : "Kolimine on käimas. Palun oota, kuni see on lõpetatud",
    "Migration started …" : "Kolimist on alustatud ...",
    "Sending..." : "Saadan...",
    "Official" : "Ametlik",
    "Approved" : "Heaks kiidetud",
    "Experimental" : "Katsetusjärgus",
    "All" : "Kõik",
    "No apps found for your version" : "Sinu versiooni jaoks ei leitud ühtegi rakendust",
    "Update to %s" : "Uuenda versioonile %s",
    "Please wait...." : "Palun oota...",
    "Error while disabling app" : "Viga rakenduse keelamisel",
    "Disable" : "Lülita välja",
    "Enable" : "Lülita sisse",
    "Error while enabling app" : "Viga rakenduse lubamisel",
    "Updating...." : "Uuendamine...",
    "Error while updating app" : "Viga rakenduse uuendamisel",
    "Updated" : "Uuendatud",
    "Uninstalling ...." : "Eemaldan...",
    "Error while uninstalling app" : "Viga rakendi eemaldamisel",
    "Uninstall" : "Eemalda",
    "App update" : "Rakenduse uuendus",
    "Valid until {date}" : "Kehtib kuni {date}",
    "Delete" : "Kustuta",
    "Select a profile picture" : "Vali profiili pilt",
    "Very weak password" : "Väga nõrk parool",
    "Weak password" : "Nõrk parool",
    "So-so password" : "Enam-vähem sobiv parool",
    "Good password" : "Hea parool",
    "Strong password" : "Väga hea parool",
    "Groups" : "Grupid",
    "Unable to delete {objName}" : "Ei suuda kustutada {objName}",
    "A valid group name must be provided" : "Sisesta nõuetele vastav grupi nimi",
    "deleted {groupName}" : "kustutatud {groupName}",
    "undo" : "tagasi",
    "no group" : "grupp puudub",
    "never" : "mitte kunagi",
    "deleted {userName}" : "kustutatud {userName}",
    "add group" : "lisa grupp",
    "A valid username must be provided" : "Sisesta nõuetele vastav kasutajatunnus",
    "A valid password must be provided" : "Sisesta nõuetele vastav parool",
    "A valid email must be provided" : "Sisesta kehtiv e-posti aadress",
    "__language_name__" : "Eesti",
    "Unlimited" : "Piiramatult",
    "Personal info" : "Isiklik info",
    "Sync clients" : "Klientide sünkroniseerimine",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Kõik (tõsised probleemid, veateated, hoiatused, info, veatuvastus)",
    "Info, warnings, errors and fatal issues" : "Info, hoiatused, veateted ja tõsised probleemid",
    "Warnings, errors and fatal issues" : "Hoiatused, veateated ja tõsised probleemid",
    "Errors and fatal issues" : "Veateated ja tõsised probleemid",
    "Fatal issues only" : "Ainult tõsised probleemid",
    "None" : "Pole",
    "Login" : "Logi sisse",
    "Plain" : "Tavatekst",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP on seadistatud eemaldama \"inline\" dokumendi blokke. See muudab mõned rakendid kasutamatuteks.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP moodul 'fileinfo' puudub. Soovitame tungivalt see lisada saavutamaks parimaid tulemusi failitüüpide tuvastamisel.",
    "System locale can not be set to a one which supports UTF-8." : "Süsteemi lokaliseeringuks ei saa panna sellist, mis toetab UTF-8-t.",
    "This means that there might be problems with certain characters in file names." : "See tähendab, et võib esineda probleeme failide nimedes mõnede sümbolitega.",
    "All checks passed." : "Kõik kontrollid on läbitud.",
    "Open documentation" : "Ava dokumentatsioon",
    "Allow apps to use the Share API" : "Luba rakendustel kasutada Share API-t",
    "Allow users to share via link" : "Luba kasutajatel lingiga jagamist ",
    "Allow public uploads" : "Luba avalikud üleslaadimised",
    "Enforce password protection" : "Sunni parooliga kaitsmist",
    "Set default expiration date" : "Määra vaikimisi aegumise kuupäev",
    "Allow users to send mail notification for shared files" : "Luba kasutajatel saata e-posti teavitusi jagatud failide kohta",
    "Expire after " : "Aegu pärast",
    "days" : "päeva",
    "Enforce expiration date" : "Sunnitud aegumise kuupäev",
    "Allow resharing" : "Luba edasijagamine",
    "Restrict users to only share with users in their groups" : "Luba kasutajatel jagada kasutajatega ainult oma grupi piires",
    "Exclude groups from sharing" : "Eemalda grupid jagamisest",
    "These groups will still be able to receive shares, but not to initiate them." : "Need grupid saavad vastu võtta jagamisi, kuid ise jagamisi algatada ei saa.",
    "Last cron job execution: %s." : "Cron käivitati viimati %s.",
    "Last cron job execution: %s. Something seems wrong." : "Cron käivitati viimati %s. Midagi tunduv valesti olevat.",
    "Cron was not executed yet!" : "Cron pole kordagi käivitatud!",
    "Execute one task with each page loaded" : "Käivita toiming igal lehe laadimisel",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php on registreeritud webcron teenuses, et käivitada fail cron.php iga 15 minuti tagant üle http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Kasuta süsteemi cron teenust, et käivitada fail cron.php iga 15 minuti järel.",
    "Enable server-side encryption" : "Luba serveripoolne krüpteerimine",
    "Enable encryption" : "Luba krüpteerimine",
    "Select default encryption module:" : "Määra vaikimisi krüpteerimise moodul:",
    "Start migration" : "Alusta kolimist",
    "This is used for sending out notifications." : "Seda kasutatakse teadete välja saatmiseks.",
    "Send mode" : "Saatmise viis",
    "Encryption" : "Krüpteerimine",
    "From address" : "Saatja aadress",
    "mail" : "e-mail",
    "Authentication method" : "Autentimise meetod",
    "Authentication required" : "Autentimine on vajalik",
    "Server address" : "Serveri aadress",
    "Port" : "Port",
    "Credentials" : "Kasutajatunnused",
    "SMTP Username" : "SMTP kasutajatunnus",
    "SMTP Password" : "SMTP parool",
    "Store credentials" : "Säilita kasutajaandmed",
    "Test email settings" : "Testi e-posti seadeid",
    "Send email" : "Saada kiri",
    "Download logfile" : "Laadi logifail alla",
    "More" : "Rohkem",
    "Less" : "Vähem",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Logifail on suurem kui 100 MB. Allalaadimine võib veidi aega võtta!",
    "What to log" : "Mida logisse sisse kanda",
    "How to do backups" : "Kuidas teha varukoopiaid",
    "Advanced monitoring" : "Lisavalikutega jälgimine",
    "Performance tuning" : "Kiiruse seadistamine",
    "Improving the config.php" : "config.php faili täiendamine",
    "Theming" : "Teemad",
    "Version" : "Versioon",
    "Developer documentation" : "Arendaja dokumentatsioon",
    "Experimental applications ahead" : "Ees on katsetusjärgus rakendused",
    "Documentation:" : "Dokumentatsioon:",
    "User documentation" : "Kasutaja dokumentatsioon",
    "Admin documentation" : "Administraatori dokumentatsioon",
    "Show description …" : "Näita kirjeldist ...",
    "Hide description …" : "Peida kirjeldus ...",
    "Enable only for specific groups" : "Luba ainult kindlad grupid",
    "Uninstall App" : "Eemada rakend",
    "Enable experimental apps" : "Luba katsetusjärgus rakenduste kasutamine",
    "SSL Root Certificates" : "SLL Juur sertifikaadid",
    "Common Name" : "Üldnimetus",
    "Valid until" : "Kehtib kuni",
    "Issued By" : "isas",
    "Valid until %s" : "Kehtib kuni %s",
    "Import root certificate" : "Impordi root sertifikaat",
    "Cheers!" : "Terekest!",
    "Administrator documentation" : "Administraatori dokumentatsioon",
    "Online documentation" : "Võrgus olev dokumentatsioon",
    "Forum" : "Foorum",
    "Issue tracker" : "Probleemide jälgija",
    "Commercial support" : "Tasuline kasutajatugi",
    "Profile picture" : "Profiili pilt",
    "Upload new" : "Laadi uus üles",
    "Remove image" : "Eemalda pilt",
    "Cancel" : "Loobu",
    "Full name" : "Täielik nimi",
    "No display name set" : "Näidatavat nime pole veel määratud",
    "Email" : "E-post",
    "Your email address" : "Sinu e-posti aadress",
    "No email address set" : "E-posti aadressi pole veel määratud",
    "You are member of the following groups:" : "Sa oled nende gruppide liige:",
    "Password" : "Parool",
    "Unable to change your password" : "Sa ei saa oma parooli muuta",
    "Current password" : "Praegune parool",
    "New password" : "Uus parool",
    "Change password" : "Muuda parooli",
    "Language" : "Keel",
    "Help translate" : "Aita tõlkida",
    "Name" : "Nimi",
    "Username" : "Kasutajanimi",
    "Done" : "Valmis",
    "Get the apps to sync your files" : "Hangi rakendusi failide sünkroniseerimiseks",
    "Desktop client" : "Töölaua klient",
    "Android app" : "Androidi rakendus",
    "iOS app" : "iOS-i rakendus",
    "Show First Run Wizard again" : "Näita veelkord Esmase Käivituse Juhendajat",
    "Show storage location" : "Näita salvestusruumi asukohta",
    "Show last log in" : "Viimane sisselogimine",
    "Send email to new user" : "Saada uuele kasutajale e-kiri",
    "Show email address" : "Näita e-posti aadressi",
    "E-Mail" : "E-post",
    "Create" : "Lisa",
    "Admin Recovery Password" : "Admini parooli taastamine",
    "Enter the recovery password in order to recover the users files during password change" : "Sisesta taasteparool kasutaja failide taastamiseks paroolivahetuse käigus",
    "Add Group" : "Lisa grupp",
    "Group" : "Grupp",
    "Everyone" : "Igaüks",
    "Admins" : "Haldurid",
    "Default Quota" : "Vaikimisi kvoot",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Palun sisesta mahupiir (nt: \"512 MB\" või \"12 GB\")",
    "Other" : "Muu",
    "Full Name" : "Täispikk nimi",
    "Group Admin for" : "Grupi admin",
    "Quota" : "Mahupiir",
    "Storage Location" : "Mahu asukoht",
    "User Backend" : "Kasutaja taustarakendus",
    "Last Login" : "Viimane sisselogimine",
    "change full name" : "Muuda täispikka nime",
    "set new password" : "määra uus parool",
    "change email address" : "muuda e-posti aadressi",
    "Default" : "Vaikeväärtus"
},
"nplurals=2; plural=(n != 1);");
